@@ -3,23 +3,22 @@ Module for basic feature manipulations, i.e. removing a feature from EOPatch, or
 the time-dependent features.
 
 Credits:
-Copyright (c) 2017-2019 Matej Aleksandrov, Matej Batič, Andrej Burja, Eva Erzin (Sinergise)
-Copyright (c) 2017-2019 Grega Milčinski, Matic Lubej, Devis Peresutti, Jernej Puc, Tomislav Slijepčević (Sinergise)
-Copyright (c) 2017-2019 Blaž Sovdat, Nejc Vesel, Jovan Višnjić, Anže Zupanc, Lojze Žust (Sinergise)
+Copyright (c) 2017-2022 Matej Aleksandrov, Matej Batič, Grega Milčinski, Domagoj Korais, Matic Lubej (Sinergise)
+Copyright (c) 2017-2022 Žiga Lukšič, Devis Peressutti, Nejc Vesel, Jovan Višnjić, Anže Zupanc (Sinergise)
+Copyright (c) 2019-2020 Jernej Puc, Lojze Žust (Sinergise)
+Copyright (c) 2017-2019 Blaž Sovdat, Andrej Burja (Sinergise)
 
 This source code is licensed under the MIT license found in the LICENSE
 file in the root directory of this source tree.
 """
 
-import logging
 import datetime as dt
+import logging
+from typing import Optional
 
 import numpy as np
 
-from sentinelhub import parse_time_interval
-from eolearn.core import EOTask, FeatureType
-from eolearn.core.utilities import renamed_and_deprecated
-
+from eolearn.core import EOTask, FeatureType, MapFeatureTask
 
 LOGGER = logging.getLogger(__name__)
 
@@ -31,6 +30,7 @@ class SimpleFilterTask(EOTask):
 
     A filter_func is a callable which takes an numpy array and returns a bool.
     """
+
     def __init__(self, feature, filter_func, filter_features=...):
         """
         :param feature: Feature in the EOPatch , e.g. feature=(FeatureType.DATA, 'bands')
@@ -40,9 +40,9 @@ class SimpleFilterTask(EOTask):
         :param filter_features: A collection of features which will be filtered
         :type filter_features: dict(FeatureType: set(str))
         """
-        self.feature = self._parse_features(feature)
+        self.feature = self.parse_feature(feature)
         self.filter_func = filter_func
-        self.filter_features = self._parse_features(filter_features)
+        self.filter_features_parser = self.get_feature_parser(filter_features)
 
     def _get_filtered_indices(self, feature_data):
         return [idx for idx, img in enumerate(feature_data) if self.filter_func(img)]
@@ -57,19 +57,17 @@ class SimpleFilterTask(EOTask):
         :return: Transformed eo patch
         :rtype: EOPatch
         """
-        feature_type, feature_name = next(self.feature(eopatch))
-
-        good_idxs = self._get_filtered_indices(eopatch[feature_type][feature_name] if feature_name is not ... else
-                                               eopatch[feature_type])
+        good_idxs = self._get_filtered_indices(eopatch[self.feature])
         if not good_idxs:
-            raise RuntimeError('EOPatch has no good indices after filtering with given filter function')
+            raise RuntimeError("EOPatch has no good indices after filtering with given filter function")
 
-        for feature_type, feature_name in self.filter_features(eopatch):
-            if feature_type.is_time_dependent():
+        for feature_type, feature_name in self.filter_features_parser.get_features(eopatch):
+            if feature_type.is_temporal():
                 if feature_type.has_dict():
                     if feature_type.contains_ndarrays():
-                        eopatch[feature_type][feature_name] = np.asarray([eopatch[feature_type][feature_name][idx] for
-                                                                          idx in good_idxs])
+                        eopatch[feature_type][feature_name] = np.asarray(
+                            [eopatch[feature_type][feature_name][idx] for idx in good_idxs]
+                        )
                     # else:
                     #     NotImplemented
                 else:
@@ -84,6 +82,7 @@ class FilterTimeSeriesTask(SimpleFilterTask):
     """
     Removes all frames in the time-series with dates outside the user specified time interval.
     """
+
     def __init__(self, start_date, end_date, filter_features=...):
         """
         :param start_date: Start date. All frames within the time-series taken after this date will be kept.
@@ -97,26 +96,16 @@ class FilterTimeSeriesTask(SimpleFilterTask):
         self.end_date = end_date
 
         if not isinstance(start_date, dt.datetime):
-            raise ValueError('Start date is not of correct type. Please provide the start_date as datetime.datetime.')
+            raise ValueError("Start date is not of correct type. Please provide the start_date as datetime.datetime.")
 
         if not isinstance(end_date, dt.datetime):
-            raise ValueError('End date is not of correct type. Please provide the end_date as datetime.datetime.')
+            raise ValueError("End date is not of correct type. Please provide the end_date as datetime.datetime.")
 
         super().__init__(FeatureType.TIMESTAMP, lambda date: start_date <= date <= end_date, filter_features)
 
-    def _update_other_data(self, eopatch):
-
-        if 'time_interval' in eopatch.meta_info:
-
-            start_time, end_time = parse_time_interval(eopatch.meta_info['time_interval'])
-            eopatch.meta_info['time_interval'] = (max(start_time, self.start_date),
-                                                  min(end_time, self.end_date))
-
-        return eopatch
-
 
 class ValueFilloutTask(EOTask):
-    """ Overwrites occurrences of a desired value with their neighbor values in either forward, backward direction or
+    """Overwrites occurrences of a desired value with their neighbor values in either forward, backward direction or
     both, along an axis.
 
     Possible fillout operations are 'f' (forward), 'b' (backward) or both, 'fb' or 'bf':
@@ -130,7 +119,7 @@ class ValueFilloutTask(EOTask):
         'bf': nan, nan, nan, 8, 5, nan, 1, 0, nan, nan -> 8, 8, 8, 8, 5, 1, 1, 0, 0, 0
     """
 
-    def __init__(self, feature, operations='fb', value=np.nan, axis=0):
+    def __init__(self, feature, operations="fb", value=np.nan, axis=0):
         """
         :param feature: A feature that must be value-filled.
         :type feature: an object supported by the :class:`FeatureParser<eolearn.core.utilities.FeatureParser>`
@@ -141,17 +130,17 @@ class ValueFilloutTask(EOTask):
         :param axis: An axis along which to fill values.
         :type axis: int
         """
-        if operations not in ['f', 'b', 'fb', 'bf']:
+        if operations not in ["f", "b", "fb", "bf"]:
             raise ValueError("'operations' parameter should be one of the following options: f, b, fb, bf.")
 
-        self.feature = next(self._parse_features(feature)())
+        self.feature = self.parse_feature(feature)
         self.operations = operations
         self.value = value
         self.axis = axis
 
     @staticmethod
-    def fill(data, value=np.nan, operation='f'):
-        """ Fills occurrences of a desired value in a 2d array with their neighbors in either forward or backward
+    def fill(data, value=np.nan, operation="f"):
+        """Fills occurrences of a desired value in a 2d array with their neighbors in either forward or backward
         direction.
 
         :param data: A 2d numpy array.
@@ -164,19 +153,19 @@ class ValueFilloutTask(EOTask):
         :rtype: numpy.ndarray
         """
         if not isinstance(data, np.ndarray) or data.ndim != 2:
-            raise ValueError('Wrong data input')
+            raise ValueError("Wrong data input")
 
-        if operation not in ['f', 'b']:
+        if operation not in ["f", "b"]:
             raise ValueError("'operation' parameter should either be 'f' (forward) or 'b' (backward)!")
 
         n_rows, n_frames = data.shape
 
         value_mask = np.isnan(data) if np.isnan(value) else (data == value)
-        init_index = 0 if operation == 'f' else (n_frames - 1)
+        init_index = 0 if operation == "f" else (n_frames - 1)
 
         idx = np.where(value_mask, init_index, np.arange(n_frames))
 
-        if operation == 'f':
+        if operation == "f":
             idx = np.maximum.accumulate(idx, axis=1)
         else:
             idx = idx[:, ::-1]
@@ -214,7 +203,29 @@ class ValueFilloutTask(EOTask):
         return eopatch
 
 
-@renamed_and_deprecated
-class FilterTimeSeries(FilterTimeSeriesTask):
-    """ A deprecated version of FilterTimeSeriesTask
+class LinearFunctionTask(MapFeatureTask):
+    """Applies a linear function to the values of input features.
+
+    Each value in the feature is modified as `x -> x * slope + intercept`. The `dtype` of the result can be customized.
     """
+
+    def __init__(
+        self, input_features, output_features=None, slope: float = 1, intercept: float = 0, dtype: Optional[str] = None
+    ):
+        """
+        :param input_features: Feature or features on which the function is used.
+        :param output_features: Feature or features for saving the result. If not provided the input_features are
+            overwritten.
+        :param slope: Slope of the function i.e. the multiplication factor.
+        :param intercept: Intercept of the function i.e. the value added.
+        :param dtype: Numpy dtype of the output feature. If not provided the dtype is determined by Numpy, so it is
+            recommended to set manually.
+        """
+        if output_features is None:
+            output_features = input_features
+        super().__init__(input_features, output_features, slope=slope, intercept=intercept, dtype=dtype)
+
+    def map_method(self, feature: np.ndarray, slope: float, intercept: float, dtype: Optional[str]) -> np.ndarray:
+        """A method where feature is multiplied by a slope"""
+        rescaled_feature = feature * slope + intercept
+        return rescaled_feature if dtype is None else rescaled_feature.astype(dtype)
