@@ -2,9 +2,9 @@
 Module for interpolating, smoothing and re-sampling features in EOPatch
 
 Credits:
-Copyright (c) 2017-2019 Matej Aleksandrov, Matej Batič, Andrej Burja, Eva Erzin (Sinergise)
-Copyright (c) 2017-2019 Grega Milčinski, Matic Lubej, Devis Peresutti, Jernej Puc, Tomislav Slijepčević (Sinergise)
-Copyright (c) 2017-2019 Blaž Sovdat, Nejc Vesel, Jovan Višnjić, Anže Zupanc, Lojze Žust (Sinergise)
+Copyright (c) 2017-2022 Matej Aleksandrov, Matej Batič, Grega Milčinski, Domagoj Korais, Matic Lubej (Sinergise)
+Copyright (c) 2017-2022 Žiga Lukšič, Devis Peressutti, Nejc Vesel, Jovan Višnjić, Anže Zupanc (Sinergise)
+Copyright (c) 2017-2019 Blaž Sovdat, Andrej Burja (Sinergise)
 Copyright (c) 2018-2019 Filip Koprivec (Jožef Stefan Institute)
 Copyright (c) 2018-2019 William Ouellette
 
@@ -12,23 +12,29 @@ This source code is licensed under the MIT license found in the LICENSE
 file in the root directory of this source tree.
 """
 
-import warnings
 import datetime as dt
 import inspect
+import warnings
 from functools import partial
 
 import dateutil
-import scipy.interpolate
 import numpy as np
-import numba
+import scipy.interpolate
 from sklearn.gaussian_process import GaussianProcessRegressor
 
-from eolearn.core import EOTask, EOPatch, FeatureType, FeatureTypeSet
-from eolearn.core.utilities import renamed_and_deprecated
+from eolearn.core import EOPatch, EOTask, FeatureType, FeatureTypeSet
+from eolearn.core.exceptions import EOUserWarning
+
+try:
+    import numba
+except ImportError as exception:
+    warnings.warn(
+        f"Failed to import numba with exception: '{exception}'. Some interpolation tasks won't work", EOUserWarning
+    )
 
 
 def base_interpolation_function(data, times, resampled_times):
-    """ Interpolates data feature
+    """Interpolates data feature
 
     :param data: Array in a shape of t x (h x w x n)
     :type data: numpy.ndarray
@@ -48,32 +54,37 @@ def base_interpolation_function(data, times, resampled_times):
             new_data = np.empty(len(resampled_times))
             new_data[:] = np.nan
         else:
-            new_data = np.interp(resampled_times.astype(np.float64),
-                                 times[mask1d].astype(np.float64),
-                                 data[:, n_feat][mask1d].astype(np.float64))
+            new_data = np.interp(
+                resampled_times.astype(np.float64),
+                times[mask1d].astype(np.float64),
+                data[:, n_feat][mask1d].astype(np.float64),
+            )
 
             true_index = np.where(mask1d)
             index_first, index_last = true_index[0][0], true_index[0][-1]
             min_time, max_time = times[index_first], times[index_last]
             first = np.where(resampled_times < min_time)[0]
             if first.size:
-                new_data[:first[-1] + 1] = np.nan
+                new_data[: first[-1] + 1] = np.nan
             last = np.where(max_time < resampled_times)[0]
             if last.size:
-                new_data[last[0]:] = np.nan
+                new_data[last[0] :] = np.nan
 
         new_bands[:, n_feat] = new_data.astype(data.dtype)
 
     return new_bands
 
 
-# pylint: disable=invalid-name
-interpolation_function = numba.njit(base_interpolation_function)
-interpolation_function_parallel = numba.njit(base_interpolation_function, parallel=True)
+try:
+    # pylint: disable=invalid-name
+    interpolation_function = numba.njit(base_interpolation_function)
+    interpolation_function_parallel = numba.njit(base_interpolation_function, parallel=True)
+except NameError:
+    pass
 
 
 class InterpolationTask(EOTask):
-    """ Main EOTask class for interpolation and resampling of time-series.
+    """Main EOTask class for interpolation and resampling of time-series.
 
     The task takes from EOPatch the specified data feature and timestamps. For each pixel in the spatial grid it
     creates an interpolation model using values that are not NaN or masked with `eopatch.mask['VALID_DATA']`. Then
@@ -115,26 +126,44 @@ class InterpolationTask(EOTask):
     :type interpolate_pixel_wise: bool
     :param interpolation_parameters: Parameters which will be propagated to ``interpolation_object``
     """
-    def __init__(self, feature, interpolation_object, *, resample_range=None, result_interval=None, mask_feature=None,
-                 copy_features=None, unknown_value=np.nan, filling_factor=10, scale_time=3600,
-                 interpolate_pixel_wise=False, **interpolation_parameters):
 
-        self.feature = self._parse_features(feature, new_names=True, default_feature_type=FeatureType.DATA,
-                                            allowed_feature_types=FeatureTypeSet.RASTER_TYPES_4D)
+    def __init__(
+        self,
+        feature,
+        interpolation_object,
+        *,
+        resample_range=None,
+        result_interval=None,
+        mask_feature=None,
+        copy_features=None,
+        unknown_value=np.nan,
+        filling_factor=10,
+        scale_time=3600,
+        interpolate_pixel_wise=False,
+        **interpolation_parameters,
+    ):
+
+        self.renamed_feature = self.parse_renamed_feature(feature, allowed_feature_types=FeatureTypeSet.RASTER_TYPES_4D)
 
         self.interpolation_object = interpolation_object
         self.resample_range = resample_range
         self.result_interval = result_interval
 
-        self.mask_feature = None if mask_feature is None else \
-            self._parse_features(mask_feature, default_feature_type=FeatureType.MASK,
-                                 allowed_feature_types={FeatureType.MASK, FeatureType.MASK_TIMELESS, FeatureType.LABEL})
+        self.mask_feature_parser = (
+            None
+            if mask_feature is None
+            else self.get_feature_parser(
+                mask_feature, allowed_feature_types={FeatureType.MASK, FeatureType.MASK_TIMELESS, FeatureType.LABEL}
+            )
+        )
 
         if resample_range is None and copy_features is not None:
             self.copy_features = None
-            warnings.warn('Argument "copy_features" will be ignored if "resample_range" is None. Nothing to copy.')
+            warnings.warn(
+                'Argument "copy_features" will be ignored if "resample_range" is None. Nothing to copy.', EOUserWarning
+            )
         else:
-            self.copy_features = None if copy_features is None else self._parse_features(copy_features, new_names=True)
+            self.copy_features_parser = None if copy_features is None else self.get_feature_parser(copy_features)
 
         self.unknown_value = unknown_value
         self.interpolation_parameters = interpolation_parameters
@@ -146,7 +175,7 @@ class InterpolationTask(EOTask):
 
     @staticmethod
     def _mask_feature_data(feature_data, mask, mask_type):
-        """ Masks values of data feature with a given mask of given mask type. The masking is done by assigning
+        """Masks values of data feature with a given mask of given mask type. The masking is done by assigning
         `numpy.nan` value.
 
         :param feature_data: Data array which will be masked
@@ -159,13 +188,15 @@ class InterpolationTask(EOTask):
         :rtype: numpy.ndarray
         """
 
-        if mask_type.is_spatial() and feature_data.shape[1: 3] != mask.shape[-3: -1]:
-            raise ValueError('Spatial dimensions of interpolation and mask feature do not match: '
-                             f'{feature_data.shape} {mask.shape}')
+        if mask_type.is_spatial() and feature_data.shape[1:3] != mask.shape[-3:-1]:
+            raise ValueError(
+                f"Spatial dimensions of interpolation and mask feature do not match: {feature_data.shape} {mask.shape}"
+            )
 
-        if mask_type.is_time_dependent() and feature_data.shape[0] != mask.shape[0]:
-            raise ValueError('Time dimension of interpolation and mask feature do not match: '
-                             f'{feature_data.shape} {mask.shape}')
+        if mask_type.is_temporal() and feature_data.shape[0] != mask.shape[0]:
+            raise ValueError(
+                f"Time dimension of interpolation and mask feature do not match: {feature_data.shape} {mask.shape}"
+            )
 
         # This allows masking each channel differently but causes some complications while masking with label
         if mask.shape[-1] != feature_data.shape[-1]:
@@ -186,7 +217,7 @@ class InterpolationTask(EOTask):
 
     @staticmethod
     def _get_start_end_nans(data):
-        """ Find NaN values in data that either start or end the time-series
+        """Find NaN values in data that either start or end the time-series
 
         Function to return a binary array of same size as data where `True` values correspond to NaN values present at
         beginning or end of time-series. NaNs internal to the time-series are not included in the binary mask.
@@ -203,13 +234,13 @@ class InterpolationTask(EOTask):
         # find NaNs that end a time-series
         end_nan = np.isnan(data)
         for idx, row in enumerate(end_nan[-2::-1]):
-            end_nan[-idx-2] = np.logical_and(row, end_nan[-idx-1])
+            end_nan[-idx - 2] = np.logical_and(row, end_nan[-idx - 1])
 
         return np.logical_or(start_nan, end_nan)
 
     @staticmethod
     def _get_unique_times(data, times):
-        """ Replace duplicate acquisitions which have same values on the chosen time scale with their average.
+        """Replace duplicate acquisitions which have same values on the chosen time scale with their average.
         The average is calculated with numpy.nanmean, meaning that NaN values are ignored when calculating the average.
 
         :param data: Array in a shape of t x nobs, where nobs = h x w x n
@@ -222,8 +253,9 @@ class InterpolationTask(EOTask):
         :rtype: numpy.array
         """
         seen = set()
-        duplicated_indices = np.array([idx for idx, item in enumerate(times) if item in seen or seen.add(item)],
-                                      dtype=int)
+        duplicated_indices = np.array(
+            [idx for idx, item in enumerate(times) if item in seen or seen.add(item)], dtype=int
+        )
         duplicated_times = np.unique(times[duplicated_indices])
 
         for time in duplicated_times:
@@ -236,37 +268,36 @@ class InterpolationTask(EOTask):
 
         return data, times
 
-    @staticmethod
-    def _copy_old_features(new_eopatch, old_eopatch, copy_features):
-        """ Copy features from old EOPatch
+    def _copy_old_features(self, new_eopatch, old_eopatch):
+        """Copy features from old EOPatch
 
         :param new_eopatch: New EOPatch container where the old features will be copied to
         :type new_eopatch: EOPatch
         :param old_eopatch: Old EOPatch container where the old features are located
         :type old_eopatch: EOPatch
-        :param copy_features: List of tuples of type (FeatureType, str) or (FeatureType, str, str) that are copied
-            over into the new EOPatch. The first string is the feature name, and the second one (optional) is a new name
-            to be used for the feature
-        :type copy_features: list((FeatureType, str) or (FeatureType, str, str))
         """
-        if copy_features:
+        if self.copy_features_parser is not None:
             existing_features = set(new_eopatch.get_feature_list())
 
-            for copy_feature_type, copy_feature_name, copy_new_feature_name in copy_features(old_eopatch):
+            renamed_features = self.copy_features_parser.get_renamed_features(old_eopatch)
+            for copy_feature_type, copy_feature_name, copy_new_feature_name in renamed_features:
                 new_feature = copy_feature_type, copy_new_feature_name
 
                 if new_feature in existing_features:
-                    raise ValueError(f'Feature {copy_new_feature_name} of {copy_feature_type} already exists in the '
-                                     'new EOPatch! Use a different name!')
+                    raise ValueError(
+                        f"Feature {copy_new_feature_name} of {copy_feature_type} already exists in the "
+                        "new EOPatch! Use a different name!"
+                    )
                 existing_features.add(new_feature)
 
-                new_eopatch[copy_feature_type][copy_new_feature_name] = \
-                    old_eopatch[copy_feature_type][copy_feature_name]
+                new_eopatch[copy_feature_type][copy_new_feature_name] = old_eopatch[copy_feature_type][
+                    copy_feature_name
+                ]
 
         return new_eopatch
 
     def interpolate_data(self, data, times, resampled_times):
-        """ Interpolates data feature
+        """Interpolates data feature
 
         :param data: Array in a shape of t x nobs, where nobs = h x w x n
         :type data: numpy.ndarray
@@ -282,9 +313,9 @@ class InterpolationTask(EOTask):
         nobs = data.shape[-1]
         if self.interpolate_pixel_wise:
             # initialise array of interpolated values
-            new_data = data if self.resample_range is None else np.full(
-                (len(resampled_times), nobs),
-                np.nan, dtype=data.dtype)
+            new_data = (
+                data if self.resample_range is None else np.full((len(resampled_times), nobs), np.nan, dtype=data.dtype)
+            )
 
             # Interpolate for each pixel, could be easily parallelized
             for obs in range(nobs):
@@ -302,17 +333,21 @@ class InterpolationTask(EOTask):
 
         # define time values as linear monotonically increasing over the observations
         const = int(self.filling_factor * (np.max(times) - np.min(times)))
-        temp_values = (times[:, np.newaxis] +
-                       const * np.arange(nobs)[np.newaxis, :].astype(np.float64))
-        res_temp_values = (resampled_times[:, np.newaxis] +
-                           const * np.arange(nobs)[np.newaxis, :].astype(np.float64))
+        temp_values = times[:, np.newaxis] + const * np.arange(nobs)[np.newaxis, :].astype(np.float64)
+        res_temp_values = resampled_times[:, np.newaxis] + const * np.arange(nobs)[np.newaxis, :].astype(np.float64)
 
         # initialise array of interpolated values
         new_data = np.full((len(resampled_times), nobs), np.nan, dtype=data.dtype)
 
         # array defining index correspondence between reference times and resampled times
-        ori2res = np.array([np.abs(resampled_times - o).argmin()
-                            if np.min(resampled_times) <= o <= np.max(resampled_times) else None for o in times])
+        ori2res = np.array(
+            [
+                np.abs(resampled_times - o).argmin()
+                if np.min(resampled_times) <= o <= np.max(resampled_times)
+                else None
+                for o in times
+            ]
+        )
 
         # find NaNs that start or end a time-series
         row_nans, col_nans = np.where(self._get_start_end_nans(data))
@@ -341,7 +376,7 @@ class InterpolationTask(EOTask):
         return new_data
 
     def get_interpolation_function(self, times, series):
-        """ Initializes interpolation model
+        """Initializes interpolation model
 
         :param times: Array of reference times in second relative to the first timestamp
         :type times: numpy.array
@@ -349,12 +384,12 @@ class InterpolationTask(EOTask):
         :type series: numpy.array
         :return: Initialized interpolation model class
         """
-        if str(inspect.getmodule(self.interpolation_object))[9:14] == 'numpy':
+        if str(inspect.getmodule(self.interpolation_object))[9:14] == "numpy":
             return partial(self.interpolation_object, xp=times, fp=series, left=np.nan, right=np.nan)
         return self.interpolation_object(times, series, **self.interpolation_parameters)
 
     def get_resampled_timestamp(self, timestamp):
-        """ Takes a list of timestamps and generates new list of timestamps according to ``resample_range``
+        """Takes a list of timestamps and generates new list of timestamps according to ``resample_range``
 
         :param timestamp: list of timestamps
         :type timestamp: list(datetime.datetime)
@@ -365,7 +400,7 @@ class InterpolationTask(EOTask):
             return timestamp
 
         if not isinstance(self.resample_range, (tuple, list)):
-            raise ValueError(f'Invalid resample_range {self.resample_range}, expected tuple')
+            raise ValueError(f"Invalid resample_range {self.resample_range}, expected tuple")
 
         if tuple(map(type, self.resample_range)) == (str, str, int):
             start_date = dateutil.parser.parse(self.resample_range[0])
@@ -380,26 +415,27 @@ class InterpolationTask(EOTask):
         elif self.resample_range and np.all([isinstance(date, dt.datetime) for date in self.resample_range]):
             days = list(self.resample_range)
         else:
-            raise ValueError('Invalid format in {self.resample_range}, expected strings or datetimes')
+            raise ValueError("Invalid format in {self.resample_range}, expected strings or datetimes")
 
         return days
 
     def execute(self, eopatch):
-        """ Execute method that processes EOPatch and returns EOPatch
-        """
+        """Execute method that processes EOPatch and returns EOPatch"""
         # pylint: disable=too-many-locals
-        feature_type, feature_name, new_feature_name = next(self.feature(eopatch))
+        feature_type, feature_name, new_feature_name = self.renamed_feature
 
         # Make a copy not to change original numpy array
         feature_data = eopatch[feature_type][feature_name].copy()
         time_num, height, width, band_num = feature_data.shape
         if time_num <= 1:
-            raise ValueError(f'Feature {(feature_type, feature_name)} has time dimension of size {time_num}, '
-                             'required at least size 2')
+            raise ValueError(
+                f"Feature {(feature_type, feature_name)} has time dimension of size {time_num}, "
+                "required at least size 2"
+            )
 
         # Apply a mask on data
-        if self.mask_feature is not None:
-            for mask_type, mask_name in self.mask_feature(eopatch):
+        if self.mask_feature_parser is not None:
+            for mask_type, mask_name in self.mask_feature_parser.get_features(eopatch):
                 negated_mask = ~eopatch[mask_type][mask_name].astype(bool)
                 feature_data = self._mask_feature_data(feature_data, negated_mask, mask_type)
 
@@ -410,10 +446,10 @@ class InterpolationTask(EOTask):
         new_eopatch = EOPatch() if self.resample_range else eopatch
 
         # Resample times
-        times = eopatch.time_series(scale_time=self.scale_time)
+        times = eopatch.get_time_series(scale_time=self.scale_time)
         new_eopatch.timestamp = self.get_resampled_timestamp(eopatch.timestamp)
         total_diff = int((new_eopatch.timestamp[0].date() - eopatch.timestamp[0].date()).total_seconds())
-        resampled_times = new_eopatch.time_series(scale_time=self.scale_time) + total_diff // self.scale_time
+        resampled_times = new_eopatch.get_time_series(scale_time=self.scale_time) + total_diff // self.scale_time
 
         # Add BBox to eopatch if it was created anew
         if new_eopatch.bbox is None:
@@ -436,40 +472,31 @@ class InterpolationTask(EOTask):
             feature_data[np.isnan(feature_data)] = self.unknown_value
 
         # Reshape back
-        new_eopatch[feature_type][new_feature_name] = np.reshape(feature_data,
-                                                                 (feature_data.shape[0], height, width, band_num))
+        new_eopatch[feature_type][new_feature_name] = np.reshape(
+            feature_data, (feature_data.shape[0], height, width, band_num)
+        )
 
         # append features from old patch
-        new_eopatch = self._copy_old_features(new_eopatch, eopatch, self.copy_features)
+        new_eopatch = self._copy_old_features(new_eopatch, eopatch)
 
         return new_eopatch
 
 
-class LegacyInterpolationTask(InterpolationTask):
-    """
-    Implements `eolearn.features.InterpolationTask` by using `scipy.interpolate.interp1d(kind='linear')`
-    """
-    def __init__(self, feature, library='numpy', **kwargs):
-        if library == 'numpy':
-            super().__init__(feature, np.interp, **kwargs)
-        else:
-            super().__init__(feature, scipy.interpolate.interp1d, kind='linear', **kwargs)
-
-
 class LinearInterpolationTask(InterpolationTask):
-    """ Implements `eolearn.features.InterpolationTask` by using `numpy.interp` and `@numba.jit(nopython=True)`
+    """Implements `eolearn.features.InterpolationTask` by using `numpy.interp` and `@numba.jit(nopython=True)`
 
     :param parallel: interpolation is calculated in parallel using as many CPUs as detected
         by the multiprocessing module.
     :type parallel: bool
     :param kwargs: parameters of InterpolationTask(EOTask)
     """
+
     def __init__(self, feature, parallel=False, **kwargs):
         self.parallel = parallel
         super().__init__(feature, np.interp, **kwargs)
 
     def interpolate_data(self, data, times, resampled_times):
-        """ Interpolates data feature
+        """Interpolates data feature
 
         :param data: Array in a shape of t x nobs, where nobs = h x w x n
         :type data: numpy.ndarray
@@ -490,14 +517,16 @@ class CubicInterpolationTask(InterpolationTask):
     """
     Implements `eolearn.features.InterpolationTask` by using `scipy.interpolate.interp1d(kind='cubic')`
     """
+
     def __init__(self, feature, **kwargs):
-        super().__init__(feature, scipy.interpolate.interp1d, kind='cubic', **kwargs)
+        super().__init__(feature, scipy.interpolate.interp1d, kind="cubic", **kwargs)
 
 
 class SplineInterpolationTask(InterpolationTask):
     """
     Implements `eolearn.features.InterpolationTask` by using `scipy.interpolate.UnivariateSpline`
     """
+
     def __init__(self, feature, *, spline_degree=3, smoothing_factor=0, **kwargs):
         super().__init__(feature, scipy.interpolate.UnivariateSpline, k=spline_degree, s=smoothing_factor, **kwargs)
 
@@ -506,6 +535,7 @@ class BSplineInterpolationTask(InterpolationTask):
     """
     Implements `eolearn.features.InterpolationTask` by using `scipy.interpolate.BSpline`
     """
+
     def __init__(self, feature, *, spline_degree=3, **kwargs):
         super().__init__(feature, scipy.interpolate.make_interp_spline, k=spline_degree, **kwargs)
 
@@ -514,6 +544,7 @@ class AkimaInterpolationTask(InterpolationTask):
     """
     Implements `eolearn.features.InterpolationTask` by using `scipy.interpolate.Akima1DInterpolator`
     """
+
     def __init__(self, feature, **kwargs):
         super().__init__(feature, scipy.interpolate.Akima1DInterpolator, **kwargs)
 
@@ -522,6 +553,7 @@ class KrigingObject:
     """
     Interpolation function like object for Kriging
     """
+
     def __init__(self, times, series, **kwargs):
         self.regressor = GaussianProcessRegressor(**kwargs)
 
@@ -532,13 +564,13 @@ class KrigingObject:
         # but this works fine (0.03% error in testing)
         self.normalizing_factor = max(times) - min(times)
 
-        self.regressor.fit(times.reshape(-1, 1)/self.normalizing_factor, series)
+        self.regressor.fit(times.reshape(-1, 1) / self.normalizing_factor, series)
         self.call_args = kwargs.get("call_args", {})
 
     def __call__(self, new_times, **kwargs):
         call_args = self.call_args.copy()
         call_args.update(kwargs)
-        return self.regressor.predict(new_times.reshape(-1, 1)/self.normalizing_factor, **call_args)
+        return self.regressor.predict(new_times.reshape(-1, 1) / self.normalizing_factor, **call_args)
 
 
 class KrigingInterpolationTask(InterpolationTask):
@@ -549,6 +581,7 @@ class KrigingInterpolationTask(InterpolationTask):
     (which may or may not be desirable).
 
     """
+
     def __init__(self, feature, **kwargs):
         super().__init__(feature, KrigingObject, interpolate_pixel_wise=True, **kwargs)
 
@@ -558,15 +591,30 @@ class ResamplingTask(InterpolationTask):
     A subclass of InterpolationTask task that works only with data with no missing, masked or
     invalid values. It always resamples timeseries to different timestamps.
     """
-    def __init__(self, feature, interpolation_object, resample_range, *, result_interval=None,
-                 unknown_value=np.nan, **interpolation_parameters):
+
+    def __init__(
+        self,
+        feature,
+        interpolation_object,
+        resample_range,
+        *,
+        result_interval=None,
+        unknown_value=np.nan,
+        **interpolation_parameters,
+    ):
         if resample_range is None:
             raise ValueError("resample_range parameter must be in form ('start_date', 'end_date', step_days)")
-        super().__init__(feature, interpolation_object, resample_range=resample_range,
-                         result_interval=result_interval, unknown_value=unknown_value, **interpolation_parameters)
+        super().__init__(
+            feature,
+            interpolation_object,
+            resample_range=resample_range,
+            result_interval=result_interval,
+            unknown_value=unknown_value,
+            **interpolation_parameters,
+        )
 
     def interpolate_data(self, data, times, resampled_times):
-        """ Interpolates data feature
+        """Interpolates data feature
 
         :param data: Array in a shape of t x nobs, where nobs = h x w x n
         :type data: numpy.ndarray
@@ -579,7 +627,7 @@ class ResamplingTask(InterpolationTask):
         :rtype: numpy.ndarray
         """
         if True in np.unique(np.isnan(data)):
-            raise ValueError('Data must not contain any masked/invalid pixels or NaN values')
+            raise ValueError("Data must not contain any masked/invalid pixels or NaN values")
 
         interp_func = self.get_interpolation_function(times, data)
 
@@ -589,7 +637,7 @@ class ResamplingTask(InterpolationTask):
         return new_data
 
     def get_interpolation_function(self, times, series):
-        """ Initializes interpolation model
+        """Initializes interpolation model
 
         :param times: Array of reference times in second relative to the first timestamp
         :type times: numpy.array
@@ -604,81 +652,24 @@ class NearestResamplingTask(ResamplingTask):
     """
     Implements `eolearn.features.ResamplingTask` by using `scipy.interpolate.interp1d(kind='nearest')`
     """
+
     def __init__(self, feature, resample_range, **kwargs):
-        super().__init__(feature, scipy.interpolate.interp1d, resample_range, kind='nearest', **kwargs)
+        super().__init__(feature, scipy.interpolate.interp1d, resample_range, kind="nearest", **kwargs)
 
 
 class LinearResamplingTask(ResamplingTask):
     """
     Implements `eolearn.features.ResamplingTask` by using `scipy.interpolate.interp1d(kind='linear')`
     """
+
     def __init__(self, feature, resample_range, **kwargs):
-        super().__init__(feature, scipy.interpolate.interp1d, resample_range, kind='linear', **kwargs)
+        super().__init__(feature, scipy.interpolate.interp1d, resample_range, kind="linear", **kwargs)
 
 
 class CubicResamplingTask(ResamplingTask):
     """
     Implements `eolearn.features.ResamplingTask` by using `scipy.interpolate.interp1d(kind='cubic')`
     """
+
     def __init__(self, feature, resample_range, **kwargs):
-        super().__init__(feature, scipy.interpolate.interp1d, resample_range, kind='cubic', **kwargs)
-
-
-@renamed_and_deprecated
-class LegacyInterpolation(LegacyInterpolationTask):
-    """ A deprecated version of LegacyInterpolationTask
-    """
-
-
-@renamed_and_deprecated
-class LinearInterpolation(LinearInterpolationTask):
-    """ A deprecated version of LinearInterpolationTask
-    """
-
-
-@renamed_and_deprecated
-class CubicInterpolation(CubicInterpolationTask):
-    """ A deprecated version of CubicInterpolationTask
-    """
-
-
-@renamed_and_deprecated
-class SplineInterpolation(SplineInterpolationTask):
-    """ A deprecated version of SplineInterpolationTask
-    """
-
-
-@renamed_and_deprecated
-class BSplineInterpolation(BSplineInterpolationTask):
-    """ A deprecated version of BSplineInterpolationTask
-    """
-
-
-@renamed_and_deprecated
-class AkimaInterpolation(AkimaInterpolationTask):
-    """ A deprecated version of AkimaInterpolationTask
-    """
-
-
-@renamed_and_deprecated
-class KrigingInterpolation(KrigingInterpolationTask):
-    """ A deprecated version of KrigingInterpolationTask
-    """
-
-
-@renamed_and_deprecated
-class NearestResampling(NearestResamplingTask):
-    """ A deprecated version of NearestResamplingTask
-    """
-
-
-@renamed_and_deprecated
-class LinearResampling(LinearResamplingTask):
-    """ A deprecated version of LinearResamplingTask
-    """
-
-
-@renamed_and_deprecated
-class CubicResampling(CubicResamplingTask):
-    """ A deprecated version of CubicResamplingTask
-    """
+        super().__init__(feature, scipy.interpolate.interp1d, resample_range, kind="cubic", **kwargs)
